.. -*- coding: utf-8 -*-

Les étiquettes permettent de classifier le contenu du site de manière
personnelle sans contrainte d'une hiérarchie pré-établie ou imposée. C'est un
moyen puissant pour regrouper tout type d'entité.

Sur les entités pouvant être étiquettées (regardez `ici`_ pour voir lesquelles),
vous devriez voir apparaître la boîte des étiquettes (si ce n'est pas le cas,
vérifiez vos `préférences utilisateurs`_), qui affiche les étiquettes appliqués
à l'entité visualisé et permet de les gérer. 

Pour ajouter une étiquette, cliquez sur le lien `ajouter les étiquettes` de la
boîte pour faire apparaître le champ d'ajout d'étiquette. Au fur et à mesure que
vous tapez dans ce champ, vous devriez voir apparaître les étiquettes existantes
correspondantes s'il en existe. Vous pouvez alors :

* sélectionner l'étiquette désirée en cliquant dessus
* appuyer sur *TAB* pour compléter automatiquement votre saisie
* finir de taper le nom d'étiquette désirée si celui-ci n'existe pas encore
* appuyer sur *ESC* pour faire disparaitre la liste déroulante

Enfin vous pouvez ajouter plusieurs étiquettes d'un coup en les séparant d'une
virgule.

Taper ensuite sur *Entrée* ou cliquez sur le lien `valider` pour ajouter les
étiquettes, ou enfin cliquez sur le lien `annuler` pour annuler l'opération.

Pour supprimer une étiquette, il suffit de cliquer sur le signe `[-]` à gauche de
celle-ci.

A noter que si vous le désirez, vous pouvez modifier vos préférences pour faire
apparaître les étiquettes dans un composant en haut ou en bas de page plutôt que
dans une boîte, les fonctionnalités étant les mêmes mis à part la possibilité de
supprimer simplement une étiquette.

.. _`ici`: eetype/Tag?vid=eschema
.. _`préférences utilisateurs`: myprefs
